<?php

namespace SimpleSAML\Error;

/**
 * Exception indicating wrong password given by user.
 *
 * @author Thomas Graff <thomas.graff@uninett.no>
 * @package SimpleSAMLphp_base
 *
 */

class InvalidCredential extends User
{
}
